######################################################################
#
# EPrints::Plugin::Sword::Unpack::XML
#
######################################################################
#
#
# Copyright 2000-2008 University of Southampton. All Rights Reserved.
# 
#  This file is part of GNU EPrints 3.
#  
#  Copyright (c) 2000-2008 University of Southampton, UK. SO17 1BJ.
#  
#  EPrints 3 is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#  
#  EPrints 3 is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#  
#  You should have received a copy of the GNU General Public License
#  along with EPrints 3; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
######################################################################

######################################################################
#
# PURPOSE:
#
#	This is a pseudo-unpacker for XML files. It just verifies
#	that there is one file of MIME type 'text/xml' and returns.
#
# METHODS:
#
# export( $plugin, %opts )
#       The method called by DepositHandler. The %opts hash contains
#       information on which files to process.
#
######################################################################

package EPrints::Plugin::Sword::Unpack::XML;

use Unicode::String qw( utf8 );

@ISA = ( "EPrints::Plugin::Convert" );

use strict;

sub new
{
	my( $class, %opts ) = @_;

	my $self = $class->SUPER::new( %opts );

	$self->{name} = "SWORD Unpacker - XML";
	$self->{visible} = "";
	$self->{accept} = "text/xml"; 
	
	return $self;
}


sub export
{
	my ( $plugin, %opts ) = @_;

	my $filename = $opts{filename};

	my @files;

	my $mime = EPrints::Sword::FileType::checktype_filename( $filename );

	if( $mime eq 'text/xml' )
	{
		push @files, $filename;
		return \@files;
	}

#	print STDERR "\n[SWORD] [XML-UNPACKER] wrong type or could not find the file ".$filename;

	return undef;		
}





1;
